'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _frauAppconfigBuilder = require('frau-appconfig-builder');

var _frauAppconfigBuilder2 = _interopRequireDefault(_frauAppconfigBuilder);

var _frauPublisher = require('frau-publisher');

var _frauPublisher2 = _interopRequireDefault(_frauPublisher);

var _frauLocalAppresolver = require('frau-local-appresolver');

var _frauLocalAppresolver2 = _interopRequireDefault(_frauLocalAppresolver);

var _errors = require('./errors');

var _errors2 = _interopRequireDefault(_errors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function FrauAppConfigPlugin(options) {

    if (options.packageFile) {

        var pjson = require(options.packageFile);

        this.config = {
            options: {
                id: pjson.appId,
                description: pjson.description,
                version: pjson.version
            },
            frauLocalAppResolver: pjson.config.frauLocalAppResolver,
            frauAppConfigBuilder: pjson.config.frauAppConfigBuilder,
            frauPublisher: pjson.config.frauPublisher
        };

        return;
    }

    this.config = {
        options: {
            id: options.appId,
            description: options.description,
            version: options.version
        },
        frauLocalAppResolver: options.frauLocalAppResolver,
        frauAppConfigBuilder: options.frauAppConfigBuilder,
        frauPublisher: options.frauPublisher
    };
}

FrauAppConfigPlugin.prototype.apply = function (compiler) {

    var errors = [];

    var _config = this.config,
        frauLocalAppResolver = _config.frauLocalAppResolver,
        frauAppConfigBuilder = _config.frauAppConfigBuilder,
        frauPublisher = _config.frauPublisher,
        options = _config.options;


    var appClass = frauLocalAppResolver ? frauLocalAppResolver.appClass : null;
    var appFile = frauAppConfigBuilder ? frauAppConfigBuilder.appFile : null;
    var envVar = frauAppConfigBuilder ? frauAppConfigBuilder.envVar : null;
    var loader = frauAppConfigBuilder ? frauAppConfigBuilder.loader : null;

    if (!options.id || !options.version || !options.description) {
        errors.push(_errors2.default.missingIdorVersionOrDescription);
    }

    if (!appFile) {
        errors.push(_errors2.default.missingAppFile);
    }

    if (!appClass) {
        errors.push(_errors2.default.missingAppClass);
    }

    var _builder = _frauAppconfigBuilder2.default.umd;

    if (loader === 'iframe') {
        _builder = _frauAppconfigBuilder2.default.iframe;
    } else if (loader === 'html') {
        _builder = _frauAppconfigBuilder2.default.html;
    }

    compiler.plugin('emit', function (compilation, cb) {

        if (errors.length > 0) {
            errors.forEach(function (err) {
                compilation.errors.push(err);
            });
            cb();
            return;
        }

        var target = void 0;

        if (envVar && process.env[envVar]) {

            var publisherOptions = _extends({}, frauPublisher, {
                version: frauPublisher.version || process.env[frauPublisher.versionVar],
                devTag: frauPublisher.devTag || process.env[frauPublisher.devTagVar]
            });

            target = _frauPublisher2.default.app(publisherOptions).getLocation() + appFile;
        } else {

            var localOptions = _frauLocalAppresolver2.default.optionsProvider.getOptions(frauAppConfigBuilder);

            target = _frauLocalAppresolver2.default.resolver(appClass, localOptions).getUrl() + appFile;
        }

        var appConfig = _builder.build(target, options);
        var appConfigString = JSON.stringify(appConfig);

        compilation.assets['appconfig.json'] = {
            source: function source() {
                return appConfigString;
            },
            size: function size() {
                return appConfigString.length;
            }
        };

        cb();
    });
};

module.exports = FrauAppConfigPlugin;